@@ -3,13 +3,14 @@ import socket
 import pickle
 import threading
 import traceback
-from omnitools import encryptedsocket_function, p, dt2yyyymmddhhmmss
+from .utils import *
+from omnitools import encryptedsocket_function, p, utf8d, dt2yyyymmddhhmmss
 
 
 __ALL__ = ["SS"]
 
 
-class SS(object):
+class SS:
     def __init__(self, functions: encryptedsocket_function = None,
                  host: str = "127.199.71.10", port: int = 39291,
                  silent: bool = False) -> None:
@@ -27,29 +28,20 @@ class SS(object):
             p("{}\tconnected\t{}".format(dt2yyyymmddhhmmss(), uid))
         try:
             while True:
-                len_response = conn.recv(4)
-                if not len_response:
-                    return None
-                import struct
-                len_response = struct.unpack('>I', len_response)[0]
-                recv = b""
-                while len(recv) < len_response:
-                    recv += conn.recv(len_response - len(recv))
-                    if not recv:
-                        break
-                request = recv
+                request = recv_all(conn)
                 if not request:
                     break
-                response = {}
                 try:
-                    request = json.loads(request)
+                    request = json.loads(utf8d(request))
                 except:
                     request = pickle.loads(request)
-                if request["command"] in self.functions:
-                    try:
+                try:
+                    if request["command"] in self.functions:
                         response = self.functions[request["command"]](*request["data"][0], **request["data"][1])
-                    except:
-                        response = traceback.format_exc()
+                    else:
+                        raise Exception("request command '{}' is not in socket functions".format(request["command"]))
+                except:
+                    response = traceback.format_exc()
                 try:
                     response = json.dumps(response).encode()
                 except TypeError:
